@@ -3,13 +3,15 @@
 import configparser
 import os
 
+from requests import Response
+
 from . import models
 from .auth import ApiTokenAuth
 from .config import Config
+from .deprecation_decorator import warn_camel_case
 from .exceptions import InitializationError
-from .models.utils import CachedProperty
+from .models.utils import cached_property
 from .requestor import Requestor, _urljoin
-from .serializer import Serializer
 
 User = models.User
 Bot = models.Bot
@@ -29,7 +31,7 @@ class CredentialManager(object):
 
         from credmgr import CredentialManager
 
-        credentialManager = CredentialManager(apiToken="LIqbGjAeep3Ws5DH3LOEQPmw8UZ6ek")
+        credential_manager = CredentialManager(api_token="LIqbGjAeep3Ws5DH3LOEQPmw8UZ6ek")
 
     .. note::
 
@@ -41,19 +43,66 @@ class CredentialManager(object):
     _default = None
     _endpoint = "/api/v1"
 
+    def _objectify_response(self, response: Response):
+        """Return a deserialized object from a response.
+
+        :param response: The response to deserialize.
+
+        :returns: A deserialized object.
+
+        """
+        data = response.json()
+        if data:
+            if isinstance(data, list):
+                return [self._objectify(item) for item in data]
+            return self._objectify(data)
+
+    def _objectify(self, data):
+        """Deserialize a dict or list into an object.
+
+        :param data: Data to be deserialized.
+
+        :returns: A credmgr object.
+
+        """
+        if data:
+            resource_type = data.get("resource_type", "")
+            model = getattr(models, resource_type, None)
+            data = self._inject(data)
+            return model.schema.load(data) if model else data
+
+    def _inject(self, data: dict):
+        """Injects the credential manager into the data.
+
+        :param data: Data to be injected.
+
+        :returns: The injected data.
+
+        """
+        if isinstance(data, dict):
+            if "resource_type" in data:
+                data["credmgr"] = self
+            for key, value in list(data.items()):
+                if isinstance(value, dict):
+                    data[key] = self._inject(value)
+                elif isinstance(value, list):
+                    data[key] = list(map(self._inject, value))
+        return data
+
+    @warn_camel_case("configName", "sessionClass", "sessionKwargs", "apiToken")
     def __init__(
-        self, configName=None, sessionClass=None, sessionKwargs=None, **kwargs
+        self, config_name=None, session_class=None, session_kwargs=None, **kwargs
     ):
         """Initialize a CredentialManager instance.
 
-        :param str configName: The name of a section in your ``.credmgr.ini`` file that
-            credmgr will load its configuration is loaded from. If ``configName`` is
+        :param str config_name: The name of a section in your ``.credmgr.ini`` file that
+            credmgr will load its configuration is loaded from. If ``config_name`` is
             ``None``, then it will look for it in the environment variable
-            ``credmgr_configName``. If it is not found there, the ``default`` section is
-            used.
-        :param Session sessionClass: A Session class that will be used to create a
+            ``credmgr_config_name``. If it is not found there, the ``default`` section
+            is used.
+        :param Session session_class: A Session class that will be used to create a
             requestor. If not set, use ``requests.Session`` (default: None).
-        :param dict sessionKwargs: Dictionary with additional keyword arguments used to
+        :param dict session_kwargs: Dictionary with additional keyword arguments used to
             initialize the session (default: None).
 
         Additional keyword arguments will be used to initialize the :class:`.Config`
@@ -63,7 +112,7 @@ class CredentialManager(object):
 
         Required settings are:
 
-        - apiToken
+        - api_token
 
         OR
 
@@ -74,7 +123,7 @@ class CredentialManager(object):
 
             Using an API Token instead of a username/password is strongly recommended!
 
-        The ``sessionClass`` and ``sessionKwargs`` allow for customization of the
+        The ``session_class`` and ``session_kwargs`` allow for customization of the
         session :class:`.CredentialManager` will use. This allows, e.g., easily adding
         behavior to the requestor or wrapping its |Session|_ in a caching layer. Example
         usage:
@@ -95,35 +144,37 @@ class CredentialManager(object):
                     return response
 
 
-            mySession = betamax.Betamax(requests.Session())
-            credentialManager = CredentialManager(
-                ..., sessionClass=JSONDebugRequestor, session=mySession
+            my_session = betamax.Betamax(requests.Session())
+            credential_manager = CredentialManager(
+                ..., session_class=JSONDebugRequestor, session=my_session
             )
 
         """
-        if sessionKwargs is None:
-            sessionKwargs = {}
-        configSection = None
+        if session_kwargs is None:
+            session_kwargs = {}
+        config_section = None
         try:
-            configSection = configName or os.getenv("credmgr_configName") or "DEFAULT"
-            self.config = Config(configSection, **kwargs)
+            config_section = (
+                config_name or os.getenv("credmgr_config_name") or "DEFAULT"
+            )
+            self.config = Config(config_section, **kwargs)
         except configparser.NoSectionError as exc:
-            if configSection is not None:
+            if config_section is not None:
                 exc.message += "\nYou provided the name of a .credmgr.ini section that doesn't exist."
             raise
 
         self._server = _urljoin(
             getattr(self.config, "server"), getattr(self.config, "endpoint")
         )
-        apiToken = getattr(self.config, "apiToken")
+        api_token = getattr(self.config, "api_token")
         username = getattr(self.config, "username")
         password = getattr(self.config, "password")
 
-        initErrorMessage = "Required settings are missing. Either 'apiToken' OR 'username' and 'password' must be specified, These settings can be provided in a .credmgr.ini file, as a keyword argument during the initialization of the `CredentialManager` class, or as an environment variable."
-        if all([apiToken, username, password]):
-            raise InitializationError(initErrorMessage)
-        if apiToken:
-            self._auth = ApiTokenAuth(apiToken)
+        init_error_message = "Required settings are missing. Either 'api_token' OR 'username' and 'password' must be specified, These settings can be provided in a .credmgr.ini file, as a keyword argument during the initialization of the `CredentialManager` class, or as an environment variable."
+        if all([api_token, username, password]):
+            raise InitializationError(init_error_message)
+        if api_token:
+            self._auth = ApiTokenAuth(api_token)
         elif username and password:
             self._auth = (username, password)
         else:
@@ -132,12 +183,13 @@ class CredentialManager(object):
             )
 
         self._requestor = Requestor(
-            self._server, self._auth, sessionClass, **sessionKwargs
+            self._server, self._auth, session_class, **session_kwargs
+        )
+        self._current_user = None
+        self._user_defaults = None
+        self.get_user_default = lambda key, default: self.user_defaults.get(
+            key, default
         )
-        self.serializer = Serializer(self)
-        self._currentUser = None
-        self._userDefaults = None
-        self.getUserDefault = lambda key, default: self.userDefaults.get(key, default)
         self.user = models.UserHelper(self)
         """An instance of :class:`.UserHelper`.
 
@@ -146,14 +198,14 @@ class CredentialManager(object):
 
         .. code-block:: python
 
-            user = credentialManager.user(1)
+            user = credential_manager.user(1)
             print(user.id)
 
         To create a :class:`.User` do:
 
         .. code-block:: python
 
-            user = credentialManager.user.create(**userKwargs)
+            user = credential_manager.user.create(**user_kwargs)
 
         See :meth:`~.UserHelper.create` for the required params.
 
@@ -166,19 +218,19 @@ class CredentialManager(object):
 
         .. code-block:: python
 
-            bot = credentialManager.bot(1)
+            bot = credential_manager.bot(1)
             print(bot.id)
 
         To create a :class:`.Bot` do:
 
         .. code-block:: python
 
-            bot = credentialManager.bot.create(**botKwargs)
+            bot = credential_manager.bot.create(**bot_kwargs)
 
         See :meth:`~.BotHelper.create` for the required params.
 
         """
-        self.redditApp = models.RedditAppHelper(self)
+        self.reddit_app = models.RedditAppHelper(self)
         """An instance of :class:`.RedditAppHelper`.
 
         Provides an interface for interacting with :class:`.RedditApp`. For example, to
@@ -186,19 +238,19 @@ class CredentialManager(object):
 
         .. code-block:: python
 
-            redditApp = credentialManager.redditApp(1)
-            print(redditApp.id)
+            reddit_app = credential_manager.reddit_app(1)
+            print(reddit_app.id)
 
         To create a :class:`.RedditApp` do:
 
         .. code-block:: python
 
-            redditApp = credentialManager.redditApp.create(**redditAppKwargs)
+            reddit_app = credential_manager.reddit_app.create(**reddit_app_kwargs)
 
         See :meth:`~.RedditAppHelper.create` for the required params.
 
         """
-        self.refreshToken = models.RefreshTokenHelper(self)
+        self.refresh_token = models.RefreshTokenHelper(self)
         """An instance of :class:`.RefreshTokenHelper`.
 
         Provides an interface for interacting with :class:`.RefreshToken`. For example
@@ -206,15 +258,15 @@ class CredentialManager(object):
 
         .. code-block:: python
 
-            refreshToken = credentialManager.refreshToken(1)
-            print(refreshToken.id)
+            refresh_token = credential_manager.refresh_token(1)
+            print(refresh_token.id)
 
         .. note::
 
             Refresh tokens cannot be manually created.
 
         """
-        self.userVerification = models.UserVerificationHelper(self)
+        self.user_verification = models.UserVerificationHelper(self)
         """An instance of :class:`.UserVerificationHelper`.
 
         Provides an interface for interacting with :class:`.UserVerification`. For
@@ -222,19 +274,21 @@ class CredentialManager(object):
 
         .. code-block:: python
 
-            userVerification = credentialManager.userVerification(1)
-            print(userVerification.id)
+            user_verification = credential_manager.user_verification(1)
+            print(user_verification.id)
 
         To create a :class:`.UserVerification` do:
 
         .. code-block:: python
 
-            userVerification = credentialManager.userVerification.create(**userVerificationKwargs)
+            user_verification = credential_manager.user_verification.create(
+                **user_verification_kwargs
+            )
 
         See :meth:`~.UserVerificationHelper.create` for the required params.
 
         """
-        self.sentryToken = models.SentryTokenHelper(self)
+        self.sentry_token = models.SentryTokenHelper(self)
         """An instance of :class:`.SentryTokenHelper`.
 
         Provides an interface for interacting with :class:`.SentryToken`. For example to
@@ -242,19 +296,19 @@ class CredentialManager(object):
 
         .. code-block:: python
 
-            sentryToken = credentialManager.sentryToken(1)
-            print(sentryToken.id)
+            sentry_token = credential_manager.sentry_token(1)
+            print(sentry_token.id)
 
         To create a :class:`.SentryToken` do:
 
         .. code-block:: python
 
-            sentryToken = credentialManager.sentryToken.create(**sentryTokenKwargs)
+            sentry_token = credential_manager.sentry_token.create(**sentry_token_kwargs)
 
         See :meth:`~.SentryTokenHelper.create` for the required params.
 
         """
-        self.databaseCredential = models.DatabaseCredentialHelper(self)
+        self.database_credential = models.DatabaseCredentialHelper(self)
         """An instance of :class:`.DatabaseCredentialHelper`.
 
         Provides an interface for interacting with :class:`.DatabaseCredential`. For
@@ -263,48 +317,48 @@ class CredentialManager(object):
 
         .. code-block:: python
 
-            databaseCredential = credentialManager.databaseCredential(1)
-            print(databaseCredential.id)
+            database_credential = credential_manager.database_credential(1)
+            print(database_credential.id)
 
         To create a :class:`.DatabaseCredential` do:
 
         .. code-block:: python
 
-            databaseCredential = credentialManager.databaseCredential.create(
-                **databaseCredentialKwargs
+            database_credential = credential_manager.database_credential.create(
+                **database_credential_kwargs
             )
 
         See :meth:`~.DatabaseCredentialHelper.create` for the required params.
 
         """
 
-    def users(self, batchSize=10, limit=None):
+    def users(self, batch_size=10, limit=None):
         """List Users.
 
-        :param int batchSize: Number of Users to return in each batch (default: ``20``)
+        :param int batch_size: Number of Users to return in each batch (default: ``20``)
         :param int limit: Maximum number of Users to return
 
         :returns: A :class:`.Paginator` to iterate through the Users
 
         """
-        return User(self).listItems(batchSize=batchSize, limit=limit)
+        return User(self).list_items(batch_size=batch_size, limit=limit)
 
-    def bots(self, batchSize=20, limit=None, owner=None):
+    def bots(self, batch_size=20, limit=None, owner=None):
         """List Bots.
 
-        :param int batchSize: Number of Bots to return in each batch (default: ``20``)
+        :param int batch_size: Number of Bots to return in each batch (default: ``20``)
         :param int limit: Maximum number of Bots to return
         :param Union[int,str,User] owner: Return Bots that are owner by this user
 
         :returns: A :class:`.Paginator` to iterate through the Bots
 
         """
-        return Bot(self).listItems(batchSize=batchSize, limit=limit, owner=owner)
+        return Bot(self).list_items(batch_size=batch_size, limit=limit, owner=owner)
 
-    def redditApps(self, batchSize=20, limit=None, owner=None):
+    def reddit_apps(self, batch_size=20, limit=None, owner=None):
         """List RedditApps.
 
-        :param int batchSize: Number of RedditApps to return in each batch (default:
+        :param int batch_size: Number of RedditApps to return in each batch (default:
             ``20``)
         :param int limit: Maximum number of RedditApps to return
         :param Union[int,str,User] owner: Return RedditApps that are owner by this user
@@ -312,12 +366,14 @@ class CredentialManager(object):
         :returns: A :class:`.Paginator` to iterate through the Reddit Apps
 
         """
-        return RedditApp(self).listItems(batchSize=batchSize, limit=limit, owner=owner)
+        return RedditApp(self).list_items(
+            batch_size=batch_size, limit=limit, owner=owner
+        )
 
-    def refreshTokens(self, batchSize=20, limit=None, owner=None):
+    def refresh_tokens(self, batch_size=20, limit=None, owner=None):
         """List RefreshTokens.
 
-        :param int batchSize: Number of RefreshTokens to return in each batch (default:
+        :param int batch_size: Number of RefreshTokens to return in each batch (default:
             ``20``)
         :param int limit: Maximum number of RefreshTokens to return
         :param Union[int,str,User] owner: Return RefreshTokens that are owned by this
@@ -331,14 +387,14 @@ class CredentialManager(object):
             :meth:`~.RedditApp.reddit` for obtaining an authorized reddit instance.
 
         """
-        return RefreshToken(self).listItems(
-            batchSize=batchSize, limit=limit, owner=owner
+        return RefreshToken(self).list_items(
+            batch_size=batch_size, limit=limit, owner=owner
         )
 
-    def userVerifications(self, batchSize=20, limit=None, owner=None):
+    def user_verifications(self, batch_size=20, limit=None, owner=None):
         """List UserVerifications.
 
-        :param int batchSize: Number of UserVerifications to return in each batch
+        :param int batch_size: Number of UserVerifications to return in each batch
             (default: ``20``)
         :param int limit: Maximum number of UserVerifications to return
         :param Union[int,str,User] owner: Return UserVerifications that are owned by
@@ -347,14 +403,14 @@ class CredentialManager(object):
         :returns: A :class:`.Paginator` to iterate through the UserVerifications.
 
         """
-        return UserVerification(self).listItems(
-            batchSize=batchSize, limit=limit, owner=owner
+        return UserVerification(self).list_items(
+            batch_size=batch_size, limit=limit, owner=owner
         )
 
-    def sentryTokens(self, batchSize=20, limit=None, owner=None):
+    def sentry_tokens(self, batch_size=20, limit=None, owner=None):
         """List SentryTokens.
 
-        :param int batchSize: Number of SentryTokens to return in each batch (default:
+        :param int batch_size: Number of SentryTokens to return in each batch (default:
             ``20``)
         :param int limit: Maximum number of SentryTokens to return
         :param Union[int,str,User] owner: Return SentryTokens that are owned by this
@@ -363,14 +419,14 @@ class CredentialManager(object):
         :returns: A :class:`.Paginator` to iterate through the SentryTokens
 
         """
-        return SentryToken(self).listItems(
-            batchSize=batchSize, limit=limit, owner=owner
+        return SentryToken(self).list_items(
+            batch_size=batch_size, limit=limit, owner=owner
         )
 
-    def databaseCredentials(self, batchSize=20, limit=None, owner=None):
+    def database_credentials(self, batch_size=20, limit=None, owner=None):
         """List DatabaseCredentials.
 
-        :param int batchSize: Number of DatabaseCredentials to return in each batch
+        :param int batch_size: Number of DatabaseCredentials to return in each batch
             (default: ``20``)
         :param int limit: Maximum number of DatabaseCredentials to return
         :param Union[int,str,User] owner: Return DatabaseCredentials that are owned by
@@ -379,23 +435,23 @@ class CredentialManager(object):
         :returns: A :class:`.Paginator` to iterate through the DatabaseCredentials
 
         """
-        return DatabaseCredential(self).listItems(
-            batchSize=batchSize, limit=limit, owner=owner
+        return DatabaseCredential(self).list_items(
+            batch_size=batch_size, limit=limit, owner=owner
         )
 
-    @CachedProperty
-    def currentUser(self) -> User:
+    @cached_property
+    def current_user(self) -> User:
         """Get the currently authenticated :class:`.User`."""
-        if not self._currentUser:
-            self._currentUser = self.get("/users/me")
-        return self._currentUser
+        if not self._current_user:
+            self._current_user = self.get("/users/me")
+        return self._current_user
 
-    @CachedProperty
-    def userDefaults(self):
+    @cached_property
+    def user_defaults(self):
         """Get the currently authenticated :class:`.User`'s default settings."""
-        if not self._userDefaults:
-            self._userDefaults = self.currentUser.defaultSettings
-        return self._userDefaults
+        if not self._user_defaults:
+            self._user_defaults = self.current_user.default_settings
+        return self._user_defaults
 
     def get(self, path, params=None):
         """Return parsed objects returned from a GET request to ``path``.
@@ -404,7 +460,7 @@ class CredentialManager(object):
         :param params: The query parameters to add to the request (default: None).
 
         """
-        return self.serializer.deserialize(
+        return self._objectify_response(
             self._requestor.request(path, "GET", params=params)
         )
 
@@ -417,7 +473,7 @@ class CredentialManager(object):
 
         """
         headers = {"Content-Type": "application/x-www-form-urlencoded"}
-        return self.serializer.deserialize(
+        return self._objectify_response(
             self._requestor.request(path, "POST", data=data, headers=headers)
         )
 
@@ -429,7 +485,7 @@ class CredentialManager(object):
             request (default: None).
 
         """
-        return self.serializer.deserialize(
+        return self._objectify_response(
             self._requestor.request(path, "PATCH", json=data)
         )
 
@@ -439,4 +495,4 @@ class CredentialManager(object):
         :param path: The path to fetch.
 
         """
-        return self._requestor.request(path, "DELETE")
+        self._requestor.request(path, "DELETE")
