@@ -26,13 +26,13 @@ class APIException(CredentialManagerException):
 
     def __str__(self):  # pragma: no cover
         """Get the message returned from str(self)."""
-        errorMessage = f"\n{self.status}: {self.url}\n{self.reason}"
+        error_message = f"\n{self.status}: {self.url}\n{self.reason}"
         if self.headers:
-            errorMessage += f"\nResponse headers: {self.headers}"
+            error_message += f"\n_response headers: {self.headers}"
         if self.body:
-            errorMessage += f"\nResponse body: {self.body}"
+            error_message += f"\n_response body: {self.body}"
 
-        return errorMessage
+        return error_message
 
 
 class Conflict(APIException):
