@@ -1,7 +1,7 @@
 """Provide the credmgr class mixins."""
 from .base import BaseModel  # NOQA
+from .base_app import BaseApp  # NOQA
 from .deletable import DeletableMixin  # NOQA
 from .editable import EditableMixin  # NOQA
 from .owner import OwnerMixin  # NOQA
-
-from .baseApp import BaseApp  # NOQA isort: skip
+from .reddit_app import RedditAppMixin  # NOQA
