@@ -1,4 +1,5 @@
 """Provide the helper classes."""
+from ..deprecation_decorator import warn_camel_case
 from ..exceptions import InitializationError
 from ..mixins import BaseModel
 from . import (
@@ -10,34 +11,34 @@ from . import (
     User,
     UserVerification,
 )
-from .utils import _resolveUser
+from .utils import _resolve_user
 
 
 class Paginator:
     """Class to handle paginated requests."""
 
-    @_resolveUser()
-    def __init__(self, credmgr, model, batchSize=20, limit=None, itemsOwner=None):
+    @_resolve_user
+    def __init__(self, credmgr, model, batch_size=20, limit=None, items_owner=None):
         """Initialize a Paginator instance.
 
         :param credmgr: An instance of :class:`.CredentialManager`.
         :param model: A CredentialManager model to list.
-        :param int batchSize: The number of items to fetch at a time. If ``batchSize``
-            is None, it will fetch them 100 at a time. (default: 20).
-        :param int limit: The maximum number of items to get.
-        :param Union[int,User,str] itemsOwner: Owner to filter the items by.
+        :param batch_size: The number of items to fetch at a time. If ``batch_size`` is
+            None, it will fetch them 100 at a time. (default: 20).
+        :param limit: The maximum number of items to get.
+        :param items_owner: Owner to filter the items by.
 
         """
-        self._credmgr = credmgr
-        self._model = model(self._credmgr)
-        self.batchSize = batchSize
-        self.limit = limit
-        self.itemsOwner = itemsOwner
-        self._itemsReturned = 0
         self._completed = False
+        self._credmgr = credmgr
+        self._current_item_index = None
+        self._items_returned = 0
+        self._model = model(self._credmgr)
         self._offset = 0
-        self._currentItemIndex = None
         self._response = None
+        self.batch_size = batch_size
+        self.items_owner = items_owner
+        self.limit = limit
 
     def __iter__(self):
         """Allow Paginator to operate as an iterator."""
@@ -45,28 +46,28 @@ class Paginator:
 
     def __next__(self):
         """Allow Paginator to operate as an generator."""
-        if self.limit is not None and self._itemsReturned >= self.limit:
+        if self.limit is not None and self._items_returned >= self.limit:
             raise StopIteration()  # pragma: no cover
 
-        if self._response is None or self._currentItemIndex >= len(self._response):
+        if self._response is None or self._current_item_index >= len(self._response):
             self._next()
 
-        self._currentItemIndex += 1
-        self._itemsReturned += 1
-        return self._response[self._currentItemIndex - 1]
+        self._current_item_index += 1
+        self._items_returned += 1
+        return self._response[self._current_item_index - 1]
 
     def _next(self):
         if self._completed:
             raise StopIteration()
-        params = dict(limit=self.batchSize, offset=self._offset)
-        if self.itemsOwner:
-            params["owner_id"] = self.itemsOwner
+        params = dict(limit=self.batch_size, offset=self._offset)
+        if self.items_owner:
+            params["owner_id"] = self.items_owner
         self._response = self._credmgr.get(self._model._path, params=params)
-        self._currentItemIndex = 0
+        self._current_item_index = 0
         if not self._response:
             raise StopIteration()  # pragma: no cover
-        if self._response and len(self._response) == self.batchSize:
-            self._offset += self.batchSize  # pragma: no cover
+        if self._response and len(self._response) == self.batch_size:
+            self._offset += self.batch_size  # pragma: no cover
         else:
             self._completed = True
 
@@ -76,36 +77,39 @@ class BaseHelper(BaseModel):
 
     _model = None
 
+    @warn_camel_case()
     def __call__(self, id=None, **kwargs):
-        """Return a fetch instance of the object."""
-        modelKwargs = {}
-        byName = False
+        """Fetch and return an instance of the object."""
+        model_kwargs = {}
+        by_name = False
         if isinstance(id, str):
             name = id
             id = None
-            if self._model._canFetchByName:
-                byName = True
-                kwargs[self._model._nameAttr] = name
+            if self._model._can_fetch_by_name:
+                by_name = True
+                kwargs[self._model._name_attr] = name
             else:
                 raise InitializationError(
                     f"Cannot get {self._model.__name__!r} by name"
                 )
         if id:
-            modelKwargs["id"] = id
-        elif self._model._canFetchByName:
-            byName = True
-            for key in self._model._apiNameMapping.keys():
+            model_kwargs["id"] = id
+        elif self._model._can_fetch_by_name:
+            by_name = True
+            if not self._model._get_by_name_attrs:
+                model_kwargs[self._model._name_attr] = kwargs[self._model._name_attr]
+            for key in self._model._get_by_name_attrs:
                 name = kwargs.get(key, None)
                 if name:
-                    modelKwargs[key] = name
+                    model_kwargs[key] = name
                 else:
                     raise InitializationError(
                         f"Missing required keyword argument, {key!r}, to fetch object by name"
                     )
         else:
             raise InitializationError("'id' is required")
-        item = self._model(self._credmgr, **modelKwargs)
-        item._fetch(byName)
+        item = self._model(self._credmgr, **model_kwargs)
+        item._fetch(by_name)
         return item
 
 
@@ -128,9 +132,9 @@ class UserHelper(BaseHelper):
 
         """
         kwargs = {}
-        byName = False
+        by_name = False
         if isinstance(id, str):
-            byName = True
+            by_name = True
             username = id
             id = None
         if id:
@@ -140,36 +144,36 @@ class UserHelper(BaseHelper):
         if not (id or username):
             raise InitializationError("At least 'id' or 'username' is required")
         item = User(self._credmgr, **kwargs)
-        item._fetch(byName)
+        item._fetch(by_name)
         return item
 
     def create(
         self,
         username,
         password,
-        defaultSettings=None,
-        isAdmin=False,
-        isActive=True,
-        isRegularUser=True,
-        isInternal=False,
-        redditUsername=None,
+        default_settings=None,
+        is_admin=False,
+        is_active=True,
+        is_regular_user=True,
+        is_internal=False,
+        reddit_username=None,
     ) -> User:
         """Create a new user.
 
-        **PERMISSIONS: At least ``isAdmin`` is required.**
+        **PERMISSIONS: At least ``is_admin`` is required.**
 
         :param str username: Username for new user (Example: ``spaz``) (required)
         :param str password: Password for new user (Example: ``supersecurepassword``)
             (required)
-        :param dict defaultSettings: Default values to use for new apps (Example:
-            ``{"databaseFlavor": "postgres", "databaseHost": "localhost"}``)
-        :param bool isAdmin: Is the user an admin? Allows the user to see all objects
+        :param dict default_settings: Default values to use for new apps (Example:
+            ``{"database_flavor": "postgres", "database_host": "localhost"}``)
+        :param bool is_admin: Is the user an admin? Allows the user to see all objects
             and create users (Default: ``False``)
-        :param bool isActive: Is the user active? Allows the user to sign in (Default:
+        :param bool is_active: Is the user active? Allows the user to sign in (Default:
             ``True``)
-        :param bool isRegularUser: (Internal use only)
-        :param bool isInternal: (Internal use only)
-        :param str redditUsername: The user's Reddit username.
+        :param bool is_regular_user: (Internal use only)
+        :param bool is_internal: (Internal use only)
+        :param str reddit_username: The user's Reddit username.
 
         :returns: User
 
@@ -178,12 +182,12 @@ class UserHelper(BaseHelper):
             self._credmgr,
             username=username,
             password=password,
-            defaultSettings=defaultSettings,
-            isAdmin=isAdmin,
-            isActive=isActive,
-            isRegularUser=isRegularUser,
-            isInternal=isInternal,
-            redditUsername=redditUsername,
+            default_settings=default_settings,
+            is_admin=is_admin,
+            is_active=is_active,
+            is_regular_user=is_regular_user,
+            is_internal=is_internal,
+            reddit_username=reddit_username,
         )
 
 
@@ -195,9 +199,9 @@ class BotHelper(BaseHelper):
     def create(
         self,
         name,
-        redditApp=None,
-        sentryToken=None,
-        databaseCredential=None,
+        reddit_app=None,
+        sentry_token=None,
+        database_credential=None,
         owner=None,
     ) -> Bot:
         """Create a new Bot.
@@ -205,9 +209,9 @@ class BotHelper(BaseHelper):
         Bots are used for grouping credentials into a single app.
 
         :param str name: Name of the Bot (required).
-        :param Union[RedditApp,int] redditApp: Reddit App the bot will use.
-        :param Union[SentryToken,int] sentryToken: Sentry Token the bot will use.
-        :param Union[DatabaseCredential,int] databaseCredential: Database Credentials
+        :param Union[RedditApp,int] reddit_app: Reddit App the bot will use.
+        :param Union[SentryToken,int] sentry_token: Sentry Token the bot will use.
+        :param Union[DatabaseCredential,int] database_credential: Database Credentials
             the bot will use.
         :param Union[User,int,str] owner: Owner of the bot. Requires Admin to create for
             other users.
@@ -218,9 +222,9 @@ class BotHelper(BaseHelper):
         return self._model._create(
             self._credmgr,
             name=name,
-            redditApp=redditApp,
-            sentryToken=sentryToken,
-            databaseCredential=databaseCredential,
+            reddit_app=reddit_app,
+            sentry_token=sentry_token,
+            database_credential=database_credential,
             owner=owner,
         )
 
@@ -233,12 +237,12 @@ class RedditAppHelper(BaseHelper):
     def create(
         self,
         name,
-        clientId,
-        userAgent=None,
-        appType="web",
-        redirectUri=None,
-        clientSecret=None,
-        appDescription=None,
+        client_id,
+        user_agent=None,
+        app_type="web",
+        redirect_uri=None,
+        client_secret=None,
+        app_description=None,
         enabled=True,
         owner=None,
     ) -> RedditApp:
@@ -247,17 +251,18 @@ class RedditAppHelper(BaseHelper):
         Reddit Apps are used for interacting with reddit.
 
         :param str name: Name of the RedditApp (required).
-        :param str clientId: Client ID of the Reddit App (required).
-        :param str userAgent: User agent used for requests to Reddit's API (required,
-            defaults to user set default, then to 'python:{name} by /u/{redditUsername}'
-            if currentUser.redditUsername is set or 'python:{name}' if it is not set).
-        :param str appType: Type of the app. One of `web`, `installed`, or `script`
+        :param str client_id: Client ID of the Reddit App (required).
+        :param str user_agent: User agent used for requests to Reddit's API (required,
+            defaults to user set default, then to 'python:{name} by
+            /u/{reddit_username}' if current_user.reddit_username is set or
+            'python:{name}' if it is not set).
+        :param str app_type: Type of the app. One of `web`, `installed`, or `script`
             (required, default: 'web').
-        :param str redirectUri: Redirect URI for Oauth2 flow. (required, defaults to
+        :param str redirect_uri: Redirect URI for Oauth2 flow. (required, defaults to
             user set default then to
             `https://credmgr.jesassn.org/oauth2/reddit_callback` if neither are set).
-        :param str clientSecret: Client secret of the Reddit App.
-        :param str appDescription: Description of the Reddit App.
+        :param str client_secret: Client secret of the Reddit App.
+        :param str app_description: Description of the Reddit App.
         :param bool enabled: Allows the app to be used.
         :param Union[User,int,str] owner: Owner of the Reddit App. Requires Admin to
             create for other users.
@@ -265,27 +270,27 @@ class RedditAppHelper(BaseHelper):
         :returns: RedditApp
 
         """
-        if not userAgent:
-            redditUsername = self._credmgr.currentUser.redditUsername
-            redditUsernameStr = ""
-            if redditUsername:
-                redditUsernameStr = f" by /u/{redditUsername}"
-            userAgent = self._credmgr.getUserDefault(
-                "user_agent", f"python:{name}{redditUsernameStr}"
+        if not user_agent:
+            reddit_username = self._credmgr.current_user.reddit_username
+            reddit_username_str = ""
+            if reddit_username:
+                reddit_username_str = f" by u/{reddit_username}"
+            user_agent = self._credmgr.get_user_default(
+                "user_agent", f"python:{name}{reddit_username_str}"
             )
-        redirectUri = self._credmgr.getUserDefault(
+        redirect_uri = self._credmgr.get_user_default(
             "redirect_uri",
-            redirectUri or "https://credmgr.jesassn.org/oauth2/reddit_callback",
+            redirect_uri or "https://credmgr.jesassn.org/oauth2/reddit_callback",
         )
         return self._model._create(
             self._credmgr,
             name=name,
-            clientId=clientId,
-            userAgent=userAgent,
-            appType=appType,
-            redirectUri=redirectUri,
-            clientSecret=clientSecret,
-            appDescription=appDescription,
+            client_id=client_id,
+            user_agent=user_agent,
+            app_type=app_type,
+            redirect_uri=redirect_uri,
+            client_secret=client_secret,
+            app_description=app_description,
             enabled=enabled,
             owner=owner,
         )
@@ -297,17 +302,17 @@ class UserVerificationHelper(BaseHelper):
     _model = UserVerification
 
     def create(
-        self, userId, redditApp, redditor=None, extraData=None, owner=None
+        self, user_id, reddit_app, redditor=None, extra_data=None, owner=None
     ) -> UserVerification:
         """Create a new User Verification.
 
-        User Verifications for verifying a redditor with a User ID.
+        User verifications for verifying a redditor with a user ID.
 
-        :param str userId: User ID to associate Redditor with (required).
-        :param Union[RedditApp,int,str] redditApp: Reddit app the User Verification is
+        :param str user_id: User ID to associate redditor with (required).
+        :param Union[RedditApp,int,str] reddit_app: Reddit app the user verification is
             for (required).
-        :param str redditor: Redditor the User Verification is for.
-        :param dict extraData: Extra JSON data to include with verification.
+        :param str redditor: Redditor the user verification is for.
+        :param dict extra_data: Extra JSON data to include with verification.
         :param int owner: Owner of the verification. Requires Admin to create for other
             users.
 
@@ -316,10 +321,10 @@ class UserVerificationHelper(BaseHelper):
         """
         return self._model._create(
             self._credmgr,
-            userId=userId,
-            redditApp=redditApp,
+            user_id=user_id,
+            reddit_app=reddit_app,
             redditor=redditor,
-            extraData=extraData,
+            extra_data=extra_data,
             owner=owner,
         )
 
@@ -353,20 +358,20 @@ class DatabaseCredentialHelper(BaseHelper):
     def create(
         self,
         name,
-        databaseFlavor="postgres",
+        database_flavor="postgres",
         database="postgres",
-        databaseHost="localhost",
-        databasePort=5432,
-        databaseUsername="postgres",
-        databasePassword=None,
-        useSsh=False,
-        sshHost=None,
-        sshPort=None,
-        sshUsername=None,
-        sshPassword=None,
-        useSshKey=False,
-        privateKey=None,
-        privateKeyPassphrase=None,
+        database_host="localhost",
+        database_port=5432,
+        database_username="postgres",
+        database_password=None,
+        use_ssh=False,
+        ssh_host=None,
+        ssh_port=None,
+        ssh_username=None,
+        ssh_password=None,
+        use_ssh_key=False,
+        private_key=None,
+        private_key_passphrase=None,
         enabled=True,
         owner=None,
     ) -> DatabaseCredential:
@@ -375,23 +380,23 @@ class DatabaseCredentialHelper(BaseHelper):
         Database Credentials are used for..ya know..databases
 
         :param str name: Name of the Database Credential (required)
-        :param str databaseFlavor: Type of database, (default: ``postgres``)
+        :param str database_flavor: Type of database, (default: ``postgres``)
         :param str database: Working database to use, (default: ``postgres``)
-        :param str databaseHost: Database server address, (default: ``localhost``)
-        :param int databasePort: Port the database server listens on, (default:
+        :param str database_host: Database server address, (default: ``localhost``)
+        :param int database_port: Port the database server listens on, (default:
             ``5432``)
-        :param str databaseUsername: Username to use to connect to the database
-        :param str databasePassword: Password to use to connect to the database
-        :param bool useSSH: Determines if the database will be connected to through a
+        :param str database_username: Username to use to connect to the database
+        :param str database_password: Password to use to connect to the database
+        :param bool use_ssh: Determines if the database will be connected to through a
             tunnel
-        :param str sshHost: The address of the server that the SSH tunnel will connect
+        :param str ssh_host: The address of the server that the SSH tunnel will connect
             to
-        :param str sshPort: The port the SSH tunnel will use
-        :param str sshUsername: Username for the SSH tunnel
-        :param str sshPassword: Password for the SSH tunnel
-        :param bool useSSHKey: Allows the credentials to be used
-        :param str privateKey: SSH private key. Note: No validation will be performed.
-        :param str privateKeyPassphrase: Passphrase for the SSH key
+        :param str ssh_port: The port the SSH tunnel will use
+        :param str ssh_username: Username for the SSH tunnel
+        :param str ssh_password: Password for the SSH tunnel
+        :param bool use_ssh_key: Allows the credentials to be used
+        :param str private_key: SSH private key. Note: No validation will be performed.
+        :param str private_key_passphrase: Passphrase for the SSH key
         :param bool enabled: Allows the credentials to be used
         :param Union[User,int,str] owner: Owner of the app. Requires Admin to create for
             other users.
@@ -402,20 +407,20 @@ class DatabaseCredentialHelper(BaseHelper):
         return self._model._create(
             self._credmgr,
             name=name,
-            databaseFlavor=databaseFlavor,
+            database_flavor=database_flavor,
             database=database,
-            databaseHost=databaseHost,
-            databasePort=databasePort,
-            databaseUsername=databaseUsername,
-            databasePassword=databasePassword,
-            useSsh=useSsh,
-            sshHost=sshHost,
-            sshPort=sshPort,
-            sshUsername=sshUsername,
-            sshPassword=sshPassword,
-            useSshKey=useSshKey,
-            privateKey=privateKey,
-            privateKeyPassphrase=privateKeyPassphrase,
+            database_host=database_host,
+            database_port=database_port,
+            database_username=database_username,
+            database_password=database_password,
+            use_ssh=use_ssh,
+            ssh_host=ssh_host,
+            ssh_port=ssh_port,
+            ssh_username=ssh_username,
+            ssh_password=ssh_password,
+            use_ssh_key=use_ssh_key,
+            private_key=private_key,
+            private_key_passphrase=private_key_passphrase,
             enabled=enabled,
             owner=owner,
         )
@@ -426,18 +431,18 @@ class RefreshTokenHelper(BaseHelper):
 
     _model = RefreshToken
 
-    def __call__(self, id=None, redditor=None, redditAppId=None):
+    def __call__(self, id=None, redditor=None, reddit_app_id=None):
         """Fetch an instance of :class:`RefreshToken`."""
         kwargs = {}
         if isinstance(id, str):
             if redditor:
-                redditAppId = redditor
+                reddit_app_id = redditor
             redditor = id
             id = None
         if id:
             kwargs["id"] = id
         if redditor:
             kwargs["redditor"] = redditor
-        if redditAppId:
-            kwargs["redditAppId"] = redditAppId
+        if reddit_app_id:
+            kwargs["reddit_app_id"] = reddit_app_id
         return super().__call__(**kwargs)
