@@ -4,10 +4,11 @@ from typing import TYPE_CHECKING, Union
 
 import praw
 
+from ..deprecation_decorator import warn_camel_case
 from ..mixins import BaseApp
-from .utils import _resolveModelFromInput, _resolveUser
+from .utils import _resolve_model_from_input, _resolve_user
 
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: no cover
     import asyncpraw
 
 
@@ -19,33 +20,32 @@ class RedditApp(BaseApp):
     .. code-block:: python
 
         bot = credmgr.bot("BotName")
-        redditApp = bot.redditApp
+        reddit_app = bot.reddit_app
 
     """
 
-    _attrTypes = {
-        **BaseApp._attrTypes,
-        "client_id": "str",
-        "client_secret": "str",
-        "app_description": "str",
-        "user_agent": "str",
-        "app_type": "str",
-        "redirect_uri": "str",
-        "state": "str",
-    }
-
-    _editableAttrs = BaseApp._editableAttrs + [
-        "clientId",
-        "clientSecret",
-        "appDescription",
-        "userAgent",
-        "appType",
-        "redirectUri",
+    _credmgr_callable = "reddit_app"
+    _editable_attrs = BaseApp._editable_attrs + [
+        "app_description",
+        "app_type",
+        "client_id",
+        "client_secret",
+        "redirect_uri",
+        "user_agent",
     ]
     _path = "/reddit_apps"
-    _credmgrCallable = "redditApp"
     _reddit = None
 
+    @classmethod
+    @property
+    def schema(cls):
+        """Return the schema for this model."""
+        if cls._schema is None:
+            from .schemas import RedditAppSchema
+
+            cls._schema = RedditAppSchema()
+        return cls._schema
+
     def __init__(self, credmgr, **kwargs):
         """Initialize a Reddit App instance.
 
@@ -54,16 +54,17 @@ class RedditApp(BaseApp):
         :param credmgr: An instance of :class:`.CredentialManager`.
         :param int id: ID of this Reddit App.
         :param str name: Name of this Reddit App.
-        :param str clientId: Client ID of this Reddit App.
-        :param str clientSecret: Client secret of the Reddit App.
-        :param str appDescription: Description of what this Reddit App is used for.
-        :param str userAgent: The user agent used to identify this Reddit App to Reddit.
-        :param str appType: Type of app this Reddit App is. One of: ``web``,
+        :param str client_id: Client ID of this Reddit App.
+        :param str client_secret: Client secret of the Reddit App.
+        :param str app_description: Description of what this Reddit App is used for.
+        :param str user_agent: The user agent used to identify this Reddit App to
+            Reddit.
+        :param str app_type: Type of app this Reddit App is. One of: ``web``,
             ``installed``, or ``script``.
-        :param str redirectUri: URL that redditors are redirected to after authorizing
+        :param str redirect_uri: URL that redditors are redirected to after authorizing
             this Reddit App to access their account.
         :param str state: Used to identify this Reddit App during the OAuth2 flow.
-        :param int ownerId: ID of the `.User` that owns this Reddit App.
+        :param int owner_id: ID of the `.User` that owns this Reddit App.
 
         """
         super().__init__(credmgr, **kwargs)
@@ -72,16 +73,24 @@ class RedditApp(BaseApp):
             self._fetched = True
 
     @staticmethod
-    @_resolveUser()
+    @_resolve_user
+    @warn_camel_case(
+        "clientId",
+        "userAgent",
+        "appType",
+        "redirectUri",
+        "clientSecret",
+        "appDescription",
+    )
     def _create(
         _credmgr,
         name,
-        clientId,
-        userAgent,
-        appType,
-        redirectUri,
-        clientSecret,
-        appDescription,
+        client_id,
+        user_agent,
+        app_type,
+        redirect_uri,
+        client_secret,
+        app_description,
         enabled,
         owner=None,
     ):
@@ -90,14 +99,14 @@ class RedditApp(BaseApp):
         Reddit Apps are used for interacting with Reddit
 
         :param str name: (required)
-        :param str clientId: Client ID of the Reddit App (required)
-        :param str userAgent: User agent used for requests to Reddit's API (required)
-        :param str appType: Type of the app. One of `web`, `installed`, or `script`
+        :param str client_id: Client ID of the Reddit App (required)
+        :param str user_agent: User agent used for requests to Reddit's API (required)
+        :param str app_type: Type of the app. One of `web`, `installed`, or `script`
             (required)
-        :param str redirectUri: Redirect URI for Oauth2 flow. Defaults to user set
+        :param str redirect_uri: Redirect URI for Oauth2 flow. Defaults to user set
             redirect uri (required)
-        :param str clientSecret: Client secret of the Reddit App
-        :param str appDescription: Description of the Reddit App
+        :param str client_secret: Client secret of the Reddit App
+        :param str app_description: Description of the Reddit App
         :param bool enabled: Allows the app to be used (defaults to `True`)
         :param Union[User,int,str] owner: Owner of the bot. Requires Admin to create for
             other users.
@@ -107,15 +116,15 @@ class RedditApp(BaseApp):
         """
         data = {
             "app_name": name,
-            "client_id": clientId,
-            "user_agent": userAgent,
-            "app_type": appType,
-            "redirect_uri": redirectUri,
+            "client_id": client_id,
+            "user_agent": user_agent,
+            "app_type": app_type,
+            "redirect_uri": redirect_uri,
         }
-        if clientSecret:
-            data["client_secret"] = clientSecret
-        if appDescription:
-            data["app_description"] = appDescription
+        if client_secret:
+            data["client_secret"] = client_secret
+        if app_description:
+            data["app_description"] = app_description
         if enabled:
             data["enabled"] = enabled
         if owner:
@@ -158,19 +167,19 @@ class RedditApp(BaseApp):
                 else:
                     reddit_class = praw.Reddit
             if redditor:
-                refreshToken = self._credmgr.refreshToken(redditor, self.id)
-                if refreshToken:
-                    extra_reddit_kwargs["refresh_token"] = refreshToken.refreshToken
+                refresh_token = self._credmgr.refresh_token(redditor, self.id)
+                if refresh_token:
+                    extra_reddit_kwargs["refresh_token"] = refresh_token.refresh_token
             self._reddit = reddit_class(
-                client_id=self.clientId,
-                client_secret=self.clientSecret,
-                user_agent=self.userAgent,
-                redirect_uri=self.redirectUri,
+                client_id=self.client_id,
+                client_secret=self.client_secret,
+                user_agent=self.user_agent,
+                redirect_uri=self.redirect_uri,
                 **extra_reddit_kwargs,
             )
         return self._reddit
 
-    def genAuthUrl(self, scopes=None, permanent=False, userVerification=None):
+    def gen_auth_url(self, scopes=None, permanent=False, user_verification=None):
         """Generate a URL for users to verify or authenticate their Reddit account.
 
         :param Union[list,str] scopes: List of scopes needed. Pass ``'all'`` for all
@@ -178,13 +187,13 @@ class RedditApp(BaseApp):
             ``['identity']``)
         :param bool permanent: Determines if a refresh token will be provided. (default:
             ``False``)
-        :param Union[UserVerification,int,str] userVerification: Link to a
+        :param Union[UserVerification,int,str] user_verification: Link to a
                 :class:`.UserVerification`
                 object. Accepted values are:
 
                 - An :class:`.UserVerification` object
                 - An :class:`.UserVerification` ``id``
-                - An ``userId`` of a :class:`.UserVerification` record.
+                - An ``user_id`` of a :class:`.UserVerification` record.
 
             If a :class:`.UserVerification` record does not exist, one will be created.
 
@@ -203,16 +212,16 @@ class RedditApp(BaseApp):
             duration = "permanent"
         else:
             duration = "temporary"
-        uVerification = _resolveModelFromInput(
-            self._credmgr, UserVerification, userVerification, "userId"
+        u_verification = _resolve_model_from_input(
+            self._credmgr, UserVerification, user_verification, "user_id"
         )
-        if not uVerification and userVerification:
-            uVerification = self._credmgr.userVerification.create(
-                userVerification, self.id
-            )
-        if uVerification:
+        if not u_verification and user_verification:
+            u_verification = self._credmgr.user_verification.create(
+                user_verification, self.id
+            ).user_id
+        if u_verification:
             state = base64.urlsafe_b64encode(
-                f"{self.state}:{uVerification}".encode()
+                f"{self.state}:{u_verification}".encode()
             ).decode()
         else:
             state = self.state
