@@ -1,15 +1,24 @@
 """Provide the SentryToken class."""
 from ..mixins import BaseApp
-from .utils import _resolveUser
+from .utils import _resolve_user
 
 
 class SentryToken(BaseApp):
     """A class for SentryToken instances."""
 
-    _attrTypes = {**BaseApp._attrTypes, "dsn": "str"}
-    _editableAttrs = BaseApp._editableAttrs + ["dsn"]
+    _credmgr_callable = "sentry_token"
+    _editable_attrs = BaseApp._editable_attrs + ["dsn"]
     _path = "/sentry_tokens"
-    _credmgrCallable = "sentryToken"
+
+    @classmethod
+    @property
+    def schema(cls):
+        """Return the schema for this model."""
+        if cls._schema is None:
+            from .schemas import SentryTokenSchema
+
+            cls._schema = SentryTokenSchema()
+        return cls._schema
 
     def __init__(self, credmgr, **kwargs):
         """Initialize a SentryToken instance.
@@ -18,13 +27,13 @@ class SentryToken(BaseApp):
         :param id: ID of the Sentry Token
         :param str name: Name of the Sentry Token.
         :param str dsn: Sentry DSN url for reporting errors.
-        :param ownerId: ID of the `.User` that owns this Sentry Token.
+        :param owner_id: ID of the `.User` that owns this Sentry Token.
 
         """
         super().__init__(credmgr, **kwargs)
 
     @staticmethod
-    @_resolveUser()
+    @_resolve_user
     def _create(_credmgr, name=None, dsn=None, owner=None):
         """Create a new Sentry Token.
 
